/******************************************************************************
 * mod_uploader / ApachePostReader.cpp
 ******************************************************************************
 * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: ApachePostReader.h 899 2005-10-24 17:25:34Z svn $
 *****************************************************************************/

#ifndef APACHE_POST_READER_H
#define APACHE_POST_READER_H

#undef PACKAGE_BUGREPORT
#undef PACKAGE_NAME
#undef PACKAGE_STRING
#undef PACKAGE_TARNAME
#undef PACKAGE_VERSION
#include "http_request.h"
#undef PACKAGE_BUGREPORT
#undef PACKAGE_NAME
#undef PACKAGE_STRING
#undef PACKAGE_TARNAME
#undef PACKAGE_VERSION

#undef strtoul

#include "PostReader.h"

#include "apr.h"
#include "apr_buckets.h"

#ifdef HAVE_CONFIG_H
#include "mod_uploader_config.h"
#endif

using namespace std;

/**
 * @brief Apache  POST ꥯȤɤ߹९饹
 */
class ApachePostReader : public PostReader
{
public:
    /**
     * 󥹥ȥ饯Ǥ
     *
     * @param[in] progress Ľ֥
     * @param[in] request ꥯ
     */
    ApachePostReader(progress *progress, request_rec *request);
    /**
     * POST ꥯȤɤ߹ߤޤ
     *
     * @param[in] buffer ɤ߹ǡ񤭹Хåե
     * @param[in] size ɤ߹ॵ
     * @param[out] read_size ºݤɤ߹
     */
    void read(char *buffer, apr_size_t size, apr_size_t *read_size);
    /**
     * ǥȥ饯Ǥ
     *
     * brigade_ ˴ޤ
     */
    ~ApachePostReader();

private:
    /**
     *  brigade ޤ
     *
     * @exception const char * brigade μ˼Ԥ
     */
    void get_brigade();

    /** ꥯ */
    request_rec *request_;
    /** brigade */
    apr_bucket_brigade *brigade_;
    /** bucket */
    apr_bucket *bucket_;
    /** Ǹޤɤ߹ɤ */
    bool is_eos_;
};

#endif

// Local Variables:
// mode: c++
// buffer-file-coding-system: euc-japan-dos
// End:
